@@ -467,7 +467,7 @@ use AnyEvent::Util ();
 
 use IO::FDPass;
 
-our $VERSION = 1.3;
+our $VERSION = 1.31;
 
 # the early fork template process
 our $EARLY;
@@ -558,7 +558,7 @@ sub _new_fork {
       require AnyEvent::Fork::Serve;
       $AnyEvent::Fork::Serve::OWNER = $parent;
       close $fh;
-      $0 = "$_[1] of $parent";
+      $0 = "$parent AnyEvent::Fork/exec";
       AnyEvent::Fork::Serve::serve ($slave);
       exit 0;
    } elsif (!$pid) {
@@ -909,6 +909,25 @@ sub run {
 
 =back
 
+
+=head2 CHILD PROCESS INTERFACE
+
+This module has a limited API for use in child processes.
+
+=over 4
+
+=item @args = AnyEvent::Fork::Serve::run_args
+
+This function, which only exists before the C<run> method is called,
+returns the arguments that would be passed to the run function, and clears
+them.
+
+This is mainly useful to get any file handles passed via C<send_fh>, but
+works for any arguments passed via C<< send_I<xxx> >> methods.
+
+=back
+
+
 =head2 EXPERIMENTAL METHODS
 
 These methods might go away completely or change behaviour, at any time.
